%	head_lims   MATLAB function 
% 	
%	reads information from the LIMS data files header: 
%   Start time, sampling rate and # of channels. 
%   Returns header structure 
%   containing start time, # of channels and sampling rate.
%
%	USAGE: [header] = head_lims(cfile,k)
%

function [header] = head_lims(cfile,k)

global fid_bin sc_factor

    char(cfile(k))
    %  	open the data file 
    fid_bin(k) = fopen(char(cfile(k)),'r','ieee-le');
    
    %   make sure position is right at the beginning
    fseek(fid_bin(k),0,-1);
    
    %	read header - analogue to rdhead.f 
    prjcod       = char(fread(fid_bin(k),3,'uint8'));
    runnum       = char(fread(fid_bin(k),7,'uint8'));
    intgr(1)     = fread(fid_bin(k),1,'int16');
    sitdes       = char(fread(fid_bin(k),20,'uint8'));
    intgr(2:6)   = fread(fid_bin(k),5,'int16');
    latdir       = char(fread(fid_bin(k),1,'uint8'));
    intgr(7:9)   = fread(fid_bin(k),3,'int16');
    lngdir       = char(fread(fid_bin(k),1,'uint8'));
    intgr(10:14) = fread(fid_bin(k),5,'int16');
    azdir        = char(fread(fid_bin(k),17,'uint8'));
    intgr(15:29) = fread(fid_bin(k),15,'int16');

    %   start time of acquisition
    start(6) = intgr(20); % year
    start(5) = intgr(19); % month
    start(4) = intgr(18); % day
    start(3) = intgr(21); % hour
    start(2) = intgr(22); % minute
    start(1) = 0;        % second   
    
    %   Stop time of acquisition 
    %   calculated from start time & duration
    duration_dd  = intgr(23);
    duration_hh  = intgr(24);
    duration_min = intgr(25);
    
    % duration can be really a dummy value:
    if (duration_dd>20) duration_dd=20; end

    add_hh = 0;
    add_dd = 0;
    add_mm = 0;
    add_yy = 0;
    mon_days = [31,28,31,30,31,30,31,31,30,31,30,31];

    stop(1)  = 0; % second
    stop(2)  = start(2) + duration_min; % minute
    if  stop(2) >= 60  
        stop(2)  = stop(2) - 60;
        add_hh = 1;
    end
    stop(3) = start(3) + duration_hh + add_hh; % hour
    if  stop(3) >= 24
        stop(3)  = stop(3) - 24;
        add_dd = 1;
    end
    stop(4) = start(4) + duration_dd + add_dd; % day
    
    kmon = mod(start(5),12);
    if (kmon==0) kmon=12; end
    while stop(4) > mon_days(kmon)
        stop(4)  = stop(4) - mon_days(start(5)+add_mm);
        add_mm = add_mm + 1;
        kmon = mod(start(5)+add_mm,12);
        if kmon==0 kmon=12; end
    end
    stop(5) = start(5) + add_mm; % month
    if  stop(5) > 12
        add_yy = 1;
        stop(5) = 1;
    end
    stop(6) = start(6) + add_yy; % year

    %   Channel Info 
    nch = 0;
    nch_grp1 = intgr(28); % channel group 1
    if  nch_grp1 > 0
        filtp1 = fread(fid_bin(k),1,'int16');
        smprt1 = fread(fid_bin(k),1,'float');
        smpin1 = char(fread(fid_bin(k),4,'uint8'));
        for ichan = 1:nch_grp1
            nch = nch+1;
            chnum       = fread(fid_bin(k),1,'int16');
            comp(chnum,1:4) = char(fread(fid_bin(k),4,'uint8'));
            gain(chnum) = fread(fid_bin(k),1,'int16');
            mapcmp(nch) = chnum;
        end
    end
        
    nch_grp2 = intgr(29); % channel group 2
    if  nch_grp2 > 0
        filtp2 = fread(fid_bin(k),1,'int16');
        smprt2 = fread(fid_bin(k),1,'float');
        smpin2 = char(fread(fid_bin(k),4,'uint8'));
        for ichan = 1:nch_grp2
            nch = nch + 1
            chnum       = fread(fid_bin(k),1,'int16');
            comp(chnum,1:4) = (fread(fid_bin(k),4,'uint8'));
            gain(chnum) = fread(fid_bin(k),1,'int16');
            mapcmp(nch) = chnum;
        end
    end
    % magnetic baselines (unused here)
    baseline(1:3) = fread(fid_bin(k),3,'int32');
    
    % position = ftell(fid_bin(k)) % -> should be 129+8*nch
    
    % sampling rate
    if  (smpin1(1:1) == 'h') | (smpin1(1:1) == 'H')
        dt = 1.0/smprt1;
    else
        dt = smprt1;
    end
        
    % find scale factors
    elength(1) = intgr(2);
    elength(2) = intgr(3);
    egain      = intgr(10);
    ad2mv      = intgr(27);
    magfac     = 10000;
    
    for ichan = 1:nch
       	sc_factor(k,ichan) = 0;
       	if ichan <= 3
         	sc_factor(k,ichan) = ad2mv/(magfac*gain(ichan));
        elseif ichan >= 4
            sc_factor(k,ichan) = (-1)*ad2mv/(egain*elength(ichan-3)*gain(ichan));
        end
    end
    
    start(1:6)
    stop(1:6)
    %%
    %% store data in structure
    header = struct('start_year',start(6),'start_mon',start(5),'start_day',start(4),...
                     'start_hr',start(3),'start_min',start(2),'start_sec',start(1),...
                     'stop_year',stop(6),'stop_mon',stop(5),'stop_day',stop(4),...
                     'stop_hr',stop(3),'stop_min',stop(2),'stop_sec',stop(1),...
                     'dt',dt,'nch',nch);  %  put into structure
    % fclose(fid_bin);

  return
  
